@@ -1,10 +1,10 @@
 /*
  *
- *  This file is part of MUMPS 5.6.2, released
- *  on Wed Oct 11 09:36:25 UTC 2023
+ *  This file is part of MUMPS 5.7.3, released
+ *  on Mon Jul 15 11:44:21 UTC 2024
  *
  *
- *  Copyright 1991-2023 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
+ *  Copyright 1991-2024 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
  *  Mumps Technologies, University of Bordeaux.
  *
  *  This version of MUMPS is provided to you free of charge. It is
@@ -68,5 +68,6 @@ typedef struct {double r,i;} mumps_double_complex;
 #define MUMPS_ARITH_SINGLE ( MUMPS_ARITH_s | MUMPS_ARITH_c )
 #define MUMPS_ARITH_DBL    ( MUMPS_ARITH_d | MUMPS_ARITH_z )
 
+#define MUMPS_OFF_T MUMPS_INT8
 
 #endif /* MUMPS_C_TYPES_H */
