@@ -1,10 +1,10 @@
 /*
  *
- *  This file is part of MUMPS 5.6.2, released
- *  on Wed Oct 11 09:36:25 UTC 2023
+ *  This file is part of MUMPS 5.7.3, released
+ *  on Mon Jul 15 11:44:21 UTC 2024
  *
  *
- *  Copyright 1991-2023 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
+ *  Copyright 1991-2024 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
  *  Mumps Technologies, University of Bordeaux.
  *
  *  This version of MUMPS is provided to you free of charge. It is
@@ -15,6 +15,10 @@
  */
 /* Utility to automatically get the sizes of Fortran types */
 #include "mumps_addr.h"
+void  MUMPS_CALL MUMPS_INT_SIZE_C( MUMPS_INT8 *i)
+{
+   *i=sizeof(MUMPS_INT);
+}
 void  MUMPS_CALL MUMPS_SIZE_C(char *a, char *b, MUMPS_INT8 *diff)
 {
     *diff = (MUMPS_INT8) (b - a);
@@ -45,3 +49,11 @@ void MUMPS_CALL MUMPS_SETDVAL_ADDR_C(DMUMPS_REAL *val, MUMPS_INT8 *addr)
 {
 *(DMUMPS_REAL*)*addr=*val;
 }
+void  MUMPS_CALL MUMPS_CLANGAOCC_C( MUMPS_INT8 *i8)
+{
+#if defined(__aocc__)
+   *i8=1;
+#else
+   *i8=0;
+#endif
+}
