@@ -1,10 +1,10 @@
 /*
  *
- *  This file is part of MUMPS 5.6.2, released
- *  on Wed Oct 11 09:36:25 UTC 2023
+ *  This file is part of MUMPS 5.7.3, released
+ *  on Mon Jul 15 11:44:21 UTC 2024
  *
  *
- *  Copyright 1991-2023 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
+ *  Copyright 1991-2024 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
  *  Mumps Technologies, University of Bordeaux.
  *
  *  This version of MUMPS is provided to you free of charge. It is
@@ -24,7 +24,7 @@
         with different int sizes */
      void MUMPS_CALL
      MUMPS_METIS_IDXSIZE(MUMPS_INT *metis_idx_size)
-     {         
+     {
        *metis_idx_size=8*sizeof(idxtype);
      }
 #  else
@@ -35,6 +35,12 @@
        /* *metis_idx_size=sizeof(idx_t); */
        *metis_idx_size=IDXTYPEWIDTH;
      }
+    /* Retrieve METIS_OPTION_NUMERING */
+     void MUMPS_CALL
+     MUMPS_METIS_OPTION_NUMBERING(MUMPS_INT *i)
+     {
+       *i=METIS_OPTION_NUMBERING;
+     }
 #  endif
 #else
   void MUMPS_CALL
@@ -42,4 +48,9 @@
   {
     *metis_int_size=-99999;
   }
+  void MUMPS_CALL
+  MUMPS_METIS_OPTION_NUMBERING(MUMPS_INT *i)
+  {
+    *i=-99999;
+  }
 #endif
